@@ -249,6 +249,8 @@ pub mod Resemble {
                 pub uuid: String,
                 pub name: String,
                 pub status: String,
+                pub dataset_url: Option<String>,
+                pub callback_uri: Option<String>,
                 pub created_at: DateTime<Utc>,
                 pub updated_at: DateTime<Utc>,
             }
@@ -256,8 +258,17 @@ pub mod Resemble {
             #[derive(Serialize, Debug)]
             pub struct VoiceInput {
                 pub name: String,
+                pub dataset_url: Option<String>,
+                pub callback_uri: Option<String>
             }
 
+            #[derive(Serialize, Debug)]
+            pub struct UpdateVoiceInput {
+                pub name: String,
+                pub callback_uri: Option<String>
+            }
+
+
             pub fn all(
                 page: usize,
                 page_size: Option<usize>,
@@ -288,7 +299,7 @@ pub mod Resemble {
                 return_json_response(response)
             }
 
-            pub fn update(uuid: String, voice: VoiceInput) -> APIResponse<UpdateResponse<Voice>> {
+            pub fn update(uuid: String, voice: UpdateVoiceInput) -> APIResponse<UpdateResponse<Voice>> {
                 let response = reqwest::blocking::Client::new()
                     .put(endpoint("v2", &format!("voices/{}", uuid)))
                     .header(AUTHORIZATION, token())
